
------------------------------------------------------------------------------------
-- Name : nUI_InfoPanel_Archy                                          
-- Copyright : Tina Kirby AKA Xrystal (C) 2010/2011 All Rights Reserved      
-- Contact : xrystal@swangen.co.uk                                           
-- Download Sites :                                                          
-- http://www.wowinterface.com
-- Versions :
-- 1.01.00 - 6th January 2011 - New Addon (4.0.3)
------------------------------------------------------------------------------------

--[[ Use Addon Wide Data Table ]]--
local addonName,addonData = ...

--[[ Localise Addon Wide Data Table Sub Tables ]]--
local Translate = addonData.Translate

--[[ Make sure we have nUI's InfoPanel network available ]]--
if not nUI_InfoPanels then nUI_InfoPanels = {}; end

--[[ Allocate ID for InfoPanel ]]--
nUI_INFOMODE_ARCHY  = 28;
nUI_INFOPANEL_ARCHY = "nUI_InfoPanel_Archy";

--[[ Set Up the InfoPanel Table ]]--
nUI_InfoPanels[nUI_INFOPANEL_ARCHY] =
{	
	enabled   = true,
	desc      = Translate["INFO_PANEL_TEXT"],	-- player friendly name/description of the panel
	label     = Translate["INFO_PANEL_LABEL"],	-- label to use on the panel selection button face
	rotation  = nUI_INFOMODE_ARCHY,				-- index or position this panel appears on/in when clicking the selector button
	full_size = true,							-- this plugin requires the entire info panel port without the button bag
	
	options  =
	{
		enabled  = true,
	},
};

--[[ Create the InfoPanel Frame Container ]]--
local plugin    = CreateFrame( "Frame", nUI_INFOPANEL_ARCHY, nUI_Dashboard.Anchor );
plugin.active   = true;

--[[ OnEvent function ]]--
local function onEvent(self,event,...)

	local arg1,arg2,arg3,arg4,arg5 = ...;
		
	if (event == "ADDON_LOADED" and arg1 == addonName) then
	
		-- Start as inactive
		plugin.active = false;
		
		-- If the addon exists make sure they are loaded
		if not IsAddOnLoaded( "Archy" ) then 
			LoadAddOn( "Archy" );
		end
		
		-- If required addon is loaded and available then activate the plugin
		if ( IsAddOnLoaded( "Archy" ) ) then 
			plugin.active = true;
		else
			plugin.active = false;
		end
		
	end
	-- At this point everything I hope will be loaded so unregister events we no longer need to track
	self:UnregisterEvent("ADDON_LOADED");	
end

plugin:SetScript( "OnEvent", onEvent );
plugin:RegisterEvent( "ADDON_LOADED" );

--[[ Disable the Plugin ]]--
disableArchy = function()
	local Archy = plugin.Archy;
	if Archy.saved_parent then
		nUI_Movers:lockFrame( Archy, false, nil );
		Archy:SetParent( Archy.saved_parent );
		Archy:SetBackdropBorderColor( Archy.border_color );
		Archy:SetBackdropColor( Archy.backdrop_color );
		Archy:SetBorderTexture("Interface\\WorldMap\\UI-ArchaeologyBlob-Outside");
	end
end

--[[ Enable the Plugin ]]--
enableArchy = function()
	local Archy = getglobal("ArchyDigSiteFrame");
	plugin.Archy = Archy;
	
	-- Save some important information
	if not Archy.saved_parent then
		Archy.saved_parent   = Archy:GetParent();
		Archy.border_color   = Archy:GetBackdropBorderColor();
		Archy.backdrop_color = Archy:GetBackdropColor();
	end
	
	-- Set the Smart Debuff Frame to fit into the info panel
	nUI_Movers:lockFrame( Archy, false, nil );
	Archy:SetParent( plugin.container );
	Archy:SetPoint( "TOPLEFT", plugin.container, "TOPLEFT", 10, -10 );
	Archy:SetPoint( "BOTTOMRIGHT", plugin.container, "BOTTOMRIGHT", -10, 10 );
	Archy:SetFrameStrata( plugin.container:GetFrameStrata() );
	Archy:SetFrameLevel( plugin.container:GetFrameLevel()+1 );
	Archy:SetBackdropBorderColor( 0, 0, 0, 0 );
	Archy:SetBackdropColor( 0, 0, 0, 0 );	
end

--[[ Resize the InfoPanel Frame ]]--
resizeArchy = function(height,width)
	local Archy   = plugin.Archy;
	nUI_Movers:lockFrame( Archy, false, nil );
	Archy:SetWidth( width ); 
	Archy:SetHeight( height ); 
end

--[[ Set Up the Infopanels Source Addon Data ]]--
selectArchy = function()
end

--[[ InfoPanel initialisation routine ]]--
plugin.initPanel = function( container, options )
	plugin.container = container;
	plugin.options   = options;
	if options and options.enabled then
		plugin.setEnabled( true );
	end
end

--[[ InfoPanel sizeChanged routine ]]--
plugin.sizeChanged = function( scale, height, width )
	local options  = plugin.options;
	plugin.scale = scale;
	
	resizeArchy(height,width);
end	

--[[ InfoPanel enabled routine ]]--
plugin.setEnabled = function( enabled )
	if plugin.enabled ~= enabled then
		plugin.enabled = enabled;
		if not enabled then
			disableArchy();
		else
			enableArchy();
			selectArchy();
		end				
	end			
end

--[[ InfoPanel selection routine ]]--
plugin.setSelected = function( selected )
	if selected ~= plugin.selected then
		plugin.selected = selected;
		if selected then
			selectArchy();
		else
		end
	end
end
